@@ -2,7 +2,9 @@ idle_time_log <- function(eventlog, units) {
 
 	idle_times <- idle_time_case(eventlog, units)
 
-	output <-summary_statistics(idle_times$idle_time)
+	idle_times %>%
+		pull(idle_time) %>%
+		summary_statistics() -> output
 
 	attr(output, "raw") <- idle_times
 	return(output)
