@@ -1,11 +1,12 @@
 
 
 processing_time_trace <- function(eventlog,
-								  units) {
+								  units,
+								  work_schedule) {
 	relative_frequency <- NULL
 	traces <- case_list(eventlog)
 	eventlog %>%
-		processing_time_case(units = units) %>%
+		processing_time_case(units = units, work_schedule = work_schedule) %>%
 		merge(traces) -> raw
 	raw %>%
 		group_by(trace) %>%
