@@ -7,7 +7,5 @@ resource_involvement_resource <- function(eventlog) {
 		group_by(!!resource_id_(eventlog), !!case_id_(eventlog)) %>%
 		summarize() %>%
 		summarize(absolute = n_distinct(!!case_id_(eventlog))) %>%
-		mutate(relative = absolute/n_cases(eventlog)) %>%
-		arrange(desc(absolute))
-
+		mutate(relative = absolute/n_cases(eventlog))
 }
